import conta.Conta;
import org.junit.Assert;
import org.junit.Test;
import pessoa.Pessoa;

public class ContaTest {

    @Test
    public void deveAtualizarOSaldoQuandoOcorrerUmDeposito(){
        //arrange
        Pessoa victor = new Pessoa("Victor Gabriel", "09586955000444", "2334343432");
        Conta Victor = new Conta(123, victor,0);
        double valorEsperado = 500;

        //act
        Victor.depositar(500);

        //assert
        Assert.assertEquals(valorEsperado,Victor.getSaldo(), 0.01);
    }
    @Test
    public void deveAtualizarOSaldoQuandoOcorrerUmSaque(){
        //arrange
        Pessoa victor = new Pessoa("Victor Gabriel", "09586955000444", "2334343432");
        Conta Victor = new Conta(111,victor,1000);
        double valorEsperado = 500;

        //act
        Victor.sacar(500);

        //assert
        Assert.assertEquals(valorEsperado,Victor.getSaldo(), 0.01);
    }
    @Test
    public void deveSacarComSucessoQuandoOcorrerUmSaqueComSaldoSuficiente(){
        //arrange
        Pessoa victor = new Pessoa("Victor Gabriel", "09586955000444", "2334343432");
        Conta Victor = new Conta(111, victor, 15000);
        Victor.depositar(1000);

        //act
        boolean foiPossivelSacar = Victor.sacar(300);

        //assert
        Assert.assertTrue(foiPossivelSacar);
    }
    @Test
    public void deveImpedirOSaqueQuandoOcorrerUmaTentativaDeSaqueSemSaldoSuficiente(){
        //arrange
        Pessoa victor = new Pessoa("Victor Gabriel", "09586955000444", "2334343432");
        Conta Victor = new Conta(999,victor);
        Victor.depositar(1000);

        //act
        boolean foiPossivelSacar = Victor.sacar(1300);

        //assert
        Assert.assertFalse(foiPossivelSacar);
    }
    @Test
    public void deveManterOSaldoQuandoOcorreUmaTentativaDeSaqueSemSaldoSuficiente(){
        //arrange
        Pessoa victor = new Pessoa("Victor Gabriel", "09586955000444", "2334343432");
        Conta Victor = new Conta(999, victor);
        Victor.depositar(1000);
        double saldoEsperado = 1000;

        //act
        Victor.sacar(1200);

        //assert
        Assert.assertEquals(saldoEsperado, Victor.getSaldo(), 0.01);
    }
    @Test
    public void deveAtualizarOSaldoDaContaDeOrigemQuandoOcorrerUmaTrasnferencia(){
        //arrange
        Pessoa victor = new Pessoa("Victor Gabriel", "09586955000444", "2334343432");
        Conta Victor = new Conta(999, victor);
        Victor.depositar(1000);

        Pessoa maria = new Pessoa("Maria Maria", "095343434444", "233909909");
        Conta Maria = new Conta(455, maria);
        Maria.depositar(2500);


        double saldoEsperado = 400;

        //act
        Victor.transferir(Maria,600);

        //assert
        Assert.assertEquals(saldoEsperado, Victor.getSaldo(), 0.01);
    }
}
